# Changelog
__________________________________________________________________

## 15 June 2021 - v1.0.1

- Initial Release

## 20 June 2021 - v1.1.0

- added syntax

## 21 June 2021 - v1.1.1

- improved autocomplete

## v1.1.5 - 21/06

- bullet lists issue rectified
- README updated

## v1.2.0 - 23/06

- global and event attributes enabled out of the box on div and section
- tTags(p=False) changed to tTags(p=True)
- Added definition lists
- global attributes enabled out of the box on table
- removed compulsory `class` args for div and section
- table `cols` renamed to `heads` for easier identification
- removed 'All rights reserved' on table.py (copyright Pandas)
- enabled multiple dts in def_list

## v1.2.3 - 24/06

- solved issue with table {col}
- solved issue with table attributes
- autoPrettify(int(186)



